pub struct GenericError {
pub message: String,
}Expand description
A special marker type for generic/standard errors that don’t have specific metadata
Fields
message: StringTrait Implementations
Sourceimpl AlienErrorData for GenericError
impl AlienErrorData for GenericError
Sourcefn http_status_code(&self) -> u16
fn http_status_code(&self) -> u16
HTTP status code for this error (defaults to 500).
Sourcefn retryable_inherit(&self) -> Option<bool>
fn retryable_inherit(&self) -> Option<bool>
Whether to inherit the retryable flag from the source error.
Returns None if this error should inherit from source, Some(value) for explicit value.
Sourcefn internal_inherit(&self) -> Option<bool>
fn internal_inherit(&self) -> Option<bool>
Whether to inherit the internal flag from the source error.
Returns None if this error should inherit from source, Some(value) for explicit value.
Sourcefn http_status_code_inherit(&self) -> Option<u16>
fn http_status_code_inherit(&self) -> Option<u16>
Whether to inherit the HTTP status code from the source error.
Returns None if this error should inherit from source, Some(value) for explicit value.
Sourceimpl Clone for GenericError
impl Clone for GenericError
Sourcefn clone(&self) -> GenericError
fn clone(&self) -> GenericError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GenericError
impl Debug for GenericError
Sourceimpl Default for GenericError
impl Default for GenericError
Sourcefn default() -> GenericError
fn default() -> GenericError
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GenericError
impl<'de> Deserialize<'de> for GenericError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for GenericError
impl Display for GenericError
Sourceimpl Error for GenericError
impl Error for GenericError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for GenericError
impl PartialEq for GenericError
Sourceimpl Serialize for GenericError
impl Serialize for GenericError
impl Eq for GenericError
impl StructuralPartialEq for GenericError