pub type Result<T, E = GenericError> = Result<T, AlienError<E>>;Expand description
Alias for the common Result type used throughout an application.
This is now generic over the error type for better type safety.
Aliased Type
pub enum Result<T, E = GenericError> {
Ok(T),
Err(AlienError<E>),
}