Result

Type Alias Result 

pub type Result<T, E = GenericError> = Result<T, AlienError<E>>;
Alias for the common Result type used throughout an application. This is now generic over the error type for better type safety.

Aliased Type

pub enum Result<T, E = GenericError> {
    Ok(T),
    Err(AlienError<E>),
}

Variants

1.0.0

Ok(T)

Contains the success value

1.0.0

Err(AlienError<E>)

Contains the error value